==> KidozSDK-0.7.0-sources.jar: com/kidoz/sdk/api/receivers/SdkReceiver.java <==
package com.kidoz.sdk.api.receivers;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;

import com.kidoz.events.EventManager;
import com.kidoz.sdk.api.general.database.DatabaseManager;
import com.kidoz.sdk.api.general.utils.ConstantDef;
import com.kidoz.sdk.api.general.utils.PropertiesObj;
import com.kidoz.sdk.api.general.utils.SDKLogger;
import com.kidoz.sdk.api.structure.IsEventRecord;

public class SdkReceiver extends BroadcastReceiver
{
    private final String TAG = SdkReceiver.class.getSimpleName();

    @Override
    public void onReceive(final Context context, Intent intent)
    {
        try
        {
            if (intent != null)
            {
                String action = intent.getAction();
                if (action != null)
                {
                    if (action.equalsIgnoreCase(Intent.ACTION_PACKAGE_ADDED))
                    {
                        if (intent.getData() != null)
                        {
                            final String packageName = intent.getData().getSchemeSpecificPart();
                            if (packageName != null)
                            {
                                new Thread(new Runnable()
                                {
                                    @Override
                                    public void run()
                                    {
                                        SDKLogger.printWarningLog("--------------------+++++++  INSTALL RECEIVER LAUNCHED ++++++ ------------------");
                                        updateInstallEvent(context, packageName);
                                    }
                                }).start();
                            }
                        }
                    }
                }
            }
        } catch (Exception e)
        {
        }
    }

    private void updateInstallEvent(Context context, String packageName)
    {
        int MAX_ACCEPTABLE_INSTALL_INTERVAL = 24 * 60 * 60 * 1000;  // 24 hours

        PropertiesObj appConfig = DatabaseManager.getInstance(context).getConfigTable().loadAppProperties();
        if (appConfig != null)
        {
            MAX_ACCEPTABLE_INSTALL_INTERVAL = appConfig.getMaxTimeToWaitForInstall() * 60 * 1000;
        }

        DatabaseManager databaseManager = DatabaseManager.getInstance(context);
        if (databaseManager != null)
        {
            IsEventRecord record = databaseManager.getIsEventTable().getRecord(packageName);
            if (record != null)
            {
                long setTime = -1;
                try
                {
                    setTime = Long.parseLong(record.getTimeStamp());
                } catch (NumberFormatException e)
                {
                    setTime = -1;
                }

                if (setTime != -1 && ((System.currentTimeMillis() - setTime) < MAX_ACCEPTABLE_INSTALL_INTERVAL))
                {
                    // Send event
                    EventManager.getInstance(context).logSponsoredContentInstallEvent(context, record.getWidgetType(), record.getStyleId(), record.getPackageName(), record.getAdvertiserId(), record.getPackageName(), record.getPositionIndex());
                    EventManager.getInstance(context).startEventsSync(context);

                    // Send event
                    if (ConstantDef.DGM)
                    {
                        SDKLogger.printWarningLog("!!!!!!!! SEND ANALYTICS EVENT OF APPLICATION INSTALLED !!!!!!!");
                        SDKLogger.printWarningLog("\ngetPackageName : " + record.getPackageName());
                        SDKLogger.printWarningLog("\ngetTimeStamp : " + record.getTimeStamp());
                        SDKLogger.printWarningLog("\ngetItemType : " + record.getContentType());
                        SDKLogger.printWarningLog("\ngetLocationInFeed : " + record.getPositionIndex());
                        SDKLogger.printWarningLog("\ngetApppName : " + record.getName());
                        SDKLogger.printWarningLog("\ngetAdvertiser ID : " + record.getAdvertiserId());
                        SDKLogger.printWarningLog("\ngetWidgetType : " + record.getWidgetType());
                        SDKLogger.printWarningLog("\ngetStyleId : " + record.getStyleId());
                    }
                }
                databaseManager.getIsEventTable().deleteRecord(packageName);
            }
        }
    }
}

==> KidozSDK-0.7.4-sources.jar: com/kidoz/sdk/api/receivers/SdkReceiver.java <==
package com.kidoz.sdk.api.receivers;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;

import com.kidoz.events.EventManager;
import com.kidoz.sdk.api.general.database.DatabaseManager;
import com.kidoz.sdk.api.general.utils.ConstantDef;
import com.kidoz.sdk.api.general.utils.PropertiesObj;
import com.kidoz.sdk.api.general.utils.SDKLogger;
import com.kidoz.sdk.api.structure.IsEventRecord;

public class SdkReceiver extends BroadcastReceiver
{
    private final String TAG = SdkReceiver.class.getSimpleName();

    @Override
    public void onReceive(final Context context, Intent intent)
    {
        try
        {
            if (intent != null)
            {
                String action = intent.getAction();
                if (action != null)
                {
                    if (action.equalsIgnoreCase(Intent.ACTION_PACKAGE_ADDED) && intent.getData() != null)
                    {

                        final String packageName = intent.getData().getSchemeSpecificPart();
                        if (packageName != null)
                        {
                            new Thread(new Runnable()
                            {
                                @Override
                                public void run()
                                {
                                    SDKLogger.printWarningLog("--------------------+++++++  INSTALL RECEIVER LAUNCHED ++++++ ------------------");
                                    updateInstallEvent(context, packageName);
                                }
                            }).start();
                        }
                    }
                }
            }
        } catch (Exception e)
        {
        }
    }

    private void updateInstallEvent(Context context, String packageName)
    {
        int MAX_ACCEPTABLE_INSTALL_INTERVAL = 24 * 60 * 60 * 1000;  // 24 hours

        PropertiesObj appConfig = DatabaseManager.getInstance(context).getConfigTable().loadAppProperties();
        if (appConfig != null)
        {
            MAX_ACCEPTABLE_INSTALL_INTERVAL = appConfig.getGPSMaxTimeToWaitForInstall() * 60 * 1000;
        }

        DatabaseManager databaseManager = DatabaseManager.getInstance(context);
        if (databaseManager != null)
        {
            IsEventRecord record = databaseManager.getIsEventTable().getRecord(packageName);
            if (record != null)
            {
                long setTime = -1;
                try
                {
                    setTime = Long.parseLong(record.getTimeStamp());
                } catch (NumberFormatException e)
                {
                    setTime = -1;
                }

                if (setTime != -1 && ((System.currentTimeMillis() - setTime) < MAX_ACCEPTABLE_INSTALL_INTERVAL))
                {
                    // Send event
                    EventManager.getInstance(context).logSponsoredContentInstallEvent(context, record.getWidgetType(), record.getStyleId(), record.getPackageName(), record.getAdvertiserId(), record.getPackageName(), record.getPositionIndex());

                    // Send event
                    if (ConstantDef.DGM)
                    {
                        SDKLogger.printWarningLog("!!!!!!!! SEND ANALYTICS EVENT OF APPLICATION INSTALLED !!!!!!!");
                        SDKLogger.printWarningLog("\ngetPackageName : " + record.getPackageName());
                        SDKLogger.printWarningLog("\ngetTimeStamp : " + record.getTimeStamp());
                        SDKLogger.printWarningLog("\ngetItemType : " + record.getContentType());
                        SDKLogger.printWarningLog("\ngetLocationInFeed : " + record.getPositionIndex());
                        SDKLogger.printWarningLog("\ngetApppName : " + record.getName());
                        SDKLogger.printWarningLog("\ngetAdvertiser ID : " + record.getAdvertiserId());
                        SDKLogger.printWarningLog("\ngetWidgetType : " + record.getWidgetType());
                        SDKLogger.printWarningLog("\ngetStyleId : " + record.getStyleId());
                    }
                }
                databaseManager.getIsEventTable().deleteRecord(packageName);
            }
        }
    }
}
